@@ -127,7 +127,8 @@ class Importer(BaseAction):
             # in the service placement.
             for service in self.deployment.get_services():
                 placement = self.deployment.get_unit_placement(service, None)
-                for container_host in placement.get_new_machines_for_containers():
+                for container_host in \
+                        placement.get_new_machines_for_containers():
                     if self.machine_exists(machine_name):
                         self.log.info("Machine %s already exists,"
                                       "skipping creation" % machine_name)
@@ -211,7 +212,9 @@ class Importer(BaseAction):
                 svc.config,
                 svc.constraints,
                 num_units,
-                placement.get(0))
+                placement.get(0),
+                charm.series or self.deployment.series,
+            )
 
             if svc.annotations:
                 self.log.debug(" Setting annotations")
@@ -234,9 +237,6 @@ class Importer(BaseAction):
             self.log.info(" Adding relation %s <-> %s", end_a, end_b)
             self.env.add_relation(end_a, end_b)
             created = True
-            # per the original, not sure the use case.
-            #self.log.debug(" Waiting 5s before next relation")
-            #time.sleep(5)
         return created
 
     def _rel_exists(self, status, end_a, end_b):
@@ -254,7 +254,7 @@ class Importer(BaseAction):
         found = False
         for r, related in rels_svc_a.items():
             if name_b in related:
-                if rem_a and not r in rem_a:
+                if rem_a and r not in rem_a:
                     continue
                 found = True
                 break
