@@ -13,14 +13,17 @@ from .utils import (
     path_exists,
     STORE_URL,
     temp_file,
-    yaml_load)
+    yaml_load,
+    get_juju_major_version,
+)
 
 
 class Charm(object):
 
     log = logging.getLogger('deployer.charm')
 
-    def __init__(self, name, path, branch, rev, build, charm_url=""):
+    def __init__(
+            self, name, path, branch, rev, build, charm_url="", data=None):
         self.name = name
         self._path = path
         self.branch = branch
@@ -28,6 +31,7 @@ class Charm(object):
         self._charm_url = charm_url
         self._build = build
         self.vcs = self.get_vcs()
+        self.data = data or {}
 
     def is_git_branch(self):
         return self.branch.startswith('git') or \
@@ -95,7 +99,7 @@ class Charm(object):
         if not store_url:
             build = data.get('build', '')
 
-        return cls(name, charm_path, branch, rev, build, store_url)
+        return cls(name, charm_path, branch, rev, build, store_url, data)
 
     def is_absolute(self):
         """Charm config points to an absolute path on disk.
@@ -138,6 +142,8 @@ class Charm(object):
     def charm_url(self):
         if self._charm_url:
             return self._charm_url
+        if get_juju_major_version() > 1:
+            return self.path
         series = os.path.basename(os.path.dirname(self.path))
         charm_name = self.metadata['name']
         return "local:%s/%s" % (series, charm_name)
@@ -171,9 +177,20 @@ class Charm(object):
             self._path = self._get_charm_store_cache()
         return self._path
 
+    @property
+    def series(self):
+        if self.data.get('series'):
+            return self.data.get('series')
+        metadata_series = self.metadata.get('series')
+        if metadata_series:
+            return metadata_series[0]
+        if self.series_path:
+            return os.path.basename(self.series_path)
+        return None
+
     @property
     def series_path(self):
-        if self.is_absolute() or not self.is_local():
+        if not self.is_local():
             return None
         return os.path.dirname(self.path)
 
