@@ -17,7 +17,8 @@ import time
 from deployer.config import ConfigStack
 from deployer.env import select_runtime
 from deployer.action import diff, importer
-from deployer.utils import ErrorExit, setup_logging, get_env_name
+from deployer.utils import (
+    ErrorExit, setup_logging, get_env_name, get_juju_major_version)
 
 
 def setup_parser():
@@ -83,7 +84,9 @@ def setup_parser():
         dest="deploy_delay", default=0)
     parser.add_argument(
         '-e', '--environment', action='store', dest='juju_env',
-        help='Deploy to a specific Juju environment.',
+        help=('Deploy to a specific Juju environment or model. '
+              'For Juju 2 models, must be specified with the '
+              '<controller>:<model> notation.'),
         default=os.getenv('JUJU_ENV'))
     parser.add_argument(
         '-o', '--override', action='append', type=str,
@@ -165,6 +168,15 @@ def run():
         sys.exit(1)
     log.debug('Using runtime %s on %s', env.__class__.__name__, env_name)
 
+    if get_juju_major_version() == 2:
+        if len(env_name.split(':')) != 2:
+            log.error("Juju 2 environment names must be in "
+                      "<controller>:<model> format.")
+            sys.exit(1)
+        if options.bootstrap:
+            log.error("Bootstrap of a Juju 2 cloud is not supported.")
+            sys.exit(1)
+
     config = ConfigStack(options.configs or [], options.series)
 
     # Destroy services and exit
