@@ -3,6 +3,7 @@ import time
 from .base import BaseEnvironment
 from ..utils import (
     ErrorExit,
+    get_juju_major_version,
     parse_constraints,
 )
 
@@ -26,6 +27,7 @@ class GoEnvironment(BaseEnvironment):
         self.options = options
         self.api_endpoint = endpoint
         self.client = None
+        self.juju_version = get_juju_major_version()
 
     def add_machine(self, series="", constraints={}):
         """Add a top level machine to the Juju environment.
@@ -54,11 +56,16 @@ class GoEnvironment(BaseEnvironment):
         if self.client:
             self.client.close()
 
+
     def connect(self):
         self.log.debug("Connecting to environment...")
+        if self.juju_version == 1:
+            cmd = ["juju", "api-endpoints"]
+        else:
+            cmd = ["juju", "get-model-config"]
         with open("/dev/null", 'w') as fh:
             self._check_call(
-                self._named_env(["juju", "api-endpoints"]),
+                self._named_env(cmd),
                 self.log, "Error getting env api endpoints, env bootstrapped?",
                 stderr=fh)
 
