@@ -291,7 +291,7 @@ class GitCharmTest(Base):
         charm.fetch()
         self.assertEqual(charm.vcs.get_cur_rev(), self.tagged_revision)
 
-    def test_vcs_fetch_with_refspec(self):
+    def test_vcs_with_extended_options(self):
         self.setup_vcs_charm()
         params = dict(self.charm_data)
         params['branch'] = \
@@ -300,11 +300,7 @@ class GitCharmTest(Base):
 
         charm = Charm.from_service(
             "scratch", self.repo_path, "trusty", params)
-        charm.fetch()
 
-        self.assertEqual(charm.vcs.get_remote_origin(),
-                         "https://review.openstack.org/" +
-                         "openstack/charm-ceilometer")
         self.assertEqual(charm.vcs.extended_options,
                          {'changeref': "286669/1"})
 
