@@ -72,7 +72,12 @@ class LiveEnvironmentTest(Base):
             services)
         for s in services:
             for k, u in status['services'][s]['units'].items():
-                self.assertIn(u['agent-state'], ("allocating", "started"))
+                try:
+                    self.assertIn(u['agent-state'],
+                                  ("allocating", "pending", "started"))
+                except KeyError:
+                    self.assertIn(u['jujustatus']['Current'],
+                                  ("allocating", "idle"))
 
     def test_add_machine(self):
         machine_name = self.env.add_machine()
