@@ -259,9 +259,11 @@ class TestImportBundle(DeployerFunctionsTestMixin, unittest.TestCase):
         # A customized Juju home is created and used during the import process.
         with self.patch_juju_home() as juju_home:
             assert not os.path.isdir(juju_home), 'directory should not exist'
-            # Ensure JUJU_HOME is included in the context when the Importer
-            # instance is run.
-            run = lambda: self.assertEqual(juju_home, os.getenv('JUJU_HOME'))
+
+            def run():
+                # Ensure JUJU_HOME is included in the context when the Importer
+                # instance is run.
+                self.assertEqual(juju_home, os.getenv('JUJU_HOME'))
             mock_importer().run = run
             self.import_bundle()
         # The JUJU_HOME directory has been created.
@@ -285,13 +287,14 @@ class TestImportBundle(DeployerFunctionsTestMixin, unittest.TestCase):
             mock.call.status(),
             mock.call.deploy(
                 'mysql', 'cs:precise/mysql-28', '', None,
-                {'arch': 'i386', 'cpu-cores': 4, 'mem': '4G'}, 2, None),
+                {'arch': 'i386', 'cpu-cores': 4, 'mem': '4G'}, 2, None,
+                'precise'),
             mock.call.set_annotation(
                 'mysql', {'gui-y': '164.547', 'gui-x': '494.347'}),
             mock.call.deploy(
                 'wordpress', 'cs:precise/wordpress-20', '',
                 {'debug': 'no', 'engine': 'nginx', 'tuning': 'single'},
-                None, 1, None),
+                None, 1, None, 'precise'),
             mock.call.set_annotation(
                 'wordpress', {'gui-y': '414.547', 'gui-x': '425.347'}),
             mock.call.add_units('mysql', 1),
