@@ -121,7 +121,6 @@ def setup_logging(verbose=False, debug=False, stream=None):
     if verbose:
         log_options.update({"loggers": {
             "deployer": {"level": "DEBUG", "propogate": True}}})
-        #log_options.update({"loggers": {""
     if debug:
         log_options.update(
             {"handlers": {"console": {"formatter": "detailed"}}})
@@ -239,10 +238,32 @@ def parse_constraints(value):
 
 
 def _get_juju_home():
-    jhome = os.environ.get("JUJU_HOME")
-    if jhome is None:
-        jhome = path_join(os.environ.get('HOME'), '.juju')
-    return jhome
+    if get_juju_major_version() == 1:
+        return (
+            os.environ.get("JUJU_HOME") or
+            path_join(os.environ.get('HOME'), '.juju')
+        )
+    return (
+        os.environ.get("JUJU_DATA") or
+        path_join(os.environ.get('HOME'), '.local', 'share', 'juju')
+    )
+
+
+_juju_major_version = None
+def get_juju_major_version():
+    global _juju_major_version
+    if _juju_major_version is None:
+        log = logging.getLogger("deployer.utils")
+        _juju_major_version = int(_check_call(
+            ["juju", "--version"], log).split('.')[0])
+    return _juju_major_version
+
+
+def get_juju_default_env():
+    if get_juju_major_version() == 1:
+        return os.environ.get("JUJU_ENV")
+    else:
+        return os.environ.get("JUJU_MODEL")
 
 
 def _check_call(params, log, *args, **kw):
@@ -258,14 +279,9 @@ def _check_call(params, log, *args, **kw):
             stderr = kw['stderr']
         output = subprocess.check_output(
             params, cwd=cwd, stderr=stderr, env=os.environ, shell=shell)
-    except subprocess.CalledProcessError, e:
+    except subprocess.CalledProcessError as e:
         if 'ignoreerr' in kw:
             return
-        #print "subprocess error"
-        #print " ".join(params), "\ncwd: %s\n" % cwd, "\n ".join(
-        # ["%s=%s" % (k, os.environ[k]) for k in os.environ
-        #     if k.startswith("JUJU")])
-        #print e.output
         log.error(*args)
         log.error("Command (%s) Output:\n\n %s", " ".join(params), e.output)
         if not max_retry or cur > max_retry:
@@ -365,20 +381,25 @@ def get_env_name(param_env_name):
     """
     if param_env_name:
         return param_env_name
-    elif os.environ.get("JUJU_ENV"):
-        return os.environ['JUJU_ENV']
+    elif get_juju_default_env():
+        return get_juju_default_env()
 
-    juju_home = _get_juju_home()
-    env_ptr = os.path.join(juju_home, "current-environment")
-    if os.path.exists(env_ptr):
-        with open(env_ptr) as fh:
-            return fh.read().strip()
+    if get_juju_major_version() == 1:
+        juju_home = _get_juju_home()
+        env_ptr = os.path.join(juju_home, "current-environment")
+        if os.path.exists(env_ptr):
+            with open(env_ptr) as fh:
+                return fh.read().strip()
 
-    with open(os.path.join(juju_home, 'environments.yaml')) as fh:
-        conf = yaml_load(fh.read())
-        if not 'default' in conf:
-            raise ValueError("No Environment specified")
-        return conf['default']
+        with open(os.path.join(juju_home, 'environments.yaml')) as fh:
+            conf = yaml_load(fh.read())
+            if 'default' not in conf:
+                raise ValueError("No Environment specified")
+            return conf['default']
+    else:
+        # Return the juju2 controller:model combo
+        log = logging.getLogger("deployer.utils")
+        return _check_call(["juju", "switch"], log).strip()
 
 
 def x_in_y(x, y):
